@@ -5,8 +5,8 @@
 # Function returning an url's domain name.
 #
 from tld import get_fld
-from ural.utils import urlsplit
-from ural.ensure_protocol import ensure_protocol
+from ural.utils import safe_urlsplit
+from ural.has_special_host import is_special_host
 
 
 def get_domain_name(url):
@@ -26,7 +26,7 @@ def get_domain_name(url):
 
 def get_hostname(url):
     try:
-        return urlsplit(ensure_protocol(url)).hostname or None
+        return safe_urlsplit(url).hostname or None
     except ValueError:
         return None
 
@@ -34,10 +34,13 @@ def get_hostname(url):
 def get_hostname_prefixes(hostname):
     result = []
 
+    if is_special_host(hostname):
+        return [hostname]
+
     if hostname:
-        domain_parts = hostname.split('.')
+        domain_parts = hostname.split(".")
 
         for i in range(len(domain_parts)):
-            result.append('.'.join(domain_parts[i:]))
+            result.append(".".join(domain_parts[i:]))
 
     return result
